==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 missatge nou</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Es connecta amb %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%s desconnectat</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>No es pot connectar amb %1. Comproveu l&apos;encaminador o el cable de xarxa.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>No es pot connectar amb %1. Si us plau, mantingueu-vos a prop de l&apos;encaminador.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Ha fallat la connexió. No es pot connectar amb %1: contrasenya incorrecta.</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Cal la contrasenya per connectar amb %1.</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>No s&apos;ha pogut trobar la xarxa WLAN 802.11 %1.</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connexió amb fil</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipus de seguretat</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primari</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de xarxa desendollat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>S&apos;autentica</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>S&apos;obté l&apos;adreça IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconnectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ha fallat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>S&apos;obté l&apos;adreça</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Xarxa amb fil %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Xarxa sense fil %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de xarxa desendollat</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ha fallat la connexió.</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Inhabilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Habilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Inhabilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Habilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Inhabilita la xarxa</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Habilita la xarxa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configuració de la xarxa</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 missatge nou</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Es connecta amb %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connectat</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%s desconnectat</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>No es pot connectar amb %1. Comproveu l&apos;encaminador o el cable de xarxa.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>No es pot connectar amb %1. Si us plau, mantingueu-vos a prop de l&apos;encaminador.</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Ha fallat la connexió. No es pot connectar amb %1: contrasenya incorrecta.</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Cal la contrasenya per connectar amb %1.</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>No s&apos;ha pogut trobar la xarxa WLAN 802.11 %1.</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connecta amb una xarxa oculta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Connecta</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nom (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punt d&apos;accés</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipus de seguretat</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfície</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Màscara de xarxa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passarel·la</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primari</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de xarxa desendollat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>S&apos;autentica</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>S&apos;obté l&apos;adreça IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconnectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ha fallat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>S&apos;obté l&apos;adreça</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Xarxa amb fil</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Xarxa amb fil %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Xarxa sense fil</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Xarxa sense fil %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositiu inhabilitat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de xarxa desendollat</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No connectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Es connecta</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connectat però sense accés a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ha fallat la connexió.</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicte d&apos;IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Inhabilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Habilita la connexió amb fil</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Inhabilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Habilita la connexió sense fil</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Inhabilita la xarxa</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Habilita la xarxa</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configuració de la xarxa</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connexió amb fil</translation>
    </message>
</context>
</TS>
